# colassigner

[![Documentation Status](https://readthedocs.org/projects/colassigner/badge/?version=latest)](https://colassigner.readthedocs.io/en/latest)
[![codeclimate](https://img.shields.io/codeclimate/maintainability/endremborza/colassigner.svg)](https://codeclimate.com/github/endremborza/colassigner)
[![codecov](https://img.shields.io/codecov/c/github/endremborza/colassigner)](https://codecov.io/gh/endremborza/colassigner)
[![pypi](https://img.shields.io/pypi/v/colassigner.svg)](https://pypi.org/project/colassigner/)

add keywords to pyproject.toml
